@@ -14,7 +14,7 @@ use List::MoreUtils qw( uniq );
 # package variables
 ########################################################################
 
-our $VERSION = '0.2.0';
+our $VERSION = '0.3.0';
 $VERSION    = eval "$VERSION";
 
 sub import
@@ -58,7 +58,10 @@ sub import
         {
             split "\n" => qx(ldd $_ 2>/dev/null ) 
         }
-        ( $^X,  values %INC );
+        (
+            $^X,
+            values %INC
+        );
 
         close $fh;
     }
